===============
Getting started
===============

Installation
============

To install bmlab, use one of the following methods:
    
* from `PyPI <https://pypi.python.org/pypi/bmlab>`_:
    ``pip install bmlab``
* from `sources <https://github.com/BrillouinMicroscopy/bmlab>`_:
    ``pip install .``


Citing bmlab
============
If you use bmlab in a scientific publication, please cite it with:

.. pull-quote::

   bmlab developers (2021), bmlab version X.X.X: Python library for the
   post-measurement analysis of real-time deformability cytometry data sets
   [Software]. Available at https://github.com/BrillouinMicroscopy/bmlab.
